Rename "libchromeos" into "libbrillo"

Renamed libchromeos[-.*] libraries into libbrillo-...

BUG: 24872993
Change-Id: Ibab1623b6a08a55cae3662e941d0d6644ff14df4
diff --git a/Android.mk b/Android.mk
index 7655afe..6485fd3 100644
--- a/Android.mk
+++ b/Android.mk
@@ -14,8 +14,8 @@
 
 LOCAL_PATH := $(call my-dir)
 
-libchromeos_cpp_extension := .cc
-libchromeos_core_sources := \
+libbrillo_cpp_extension := .cc
+libbrillo_core_sources := \
     brillo/backoff_entry.cc \
     brillo/data_encoding.cc \
     brillo/errors/error.cc \
@@ -35,16 +35,16 @@
     brillo/type_name_undecorate.cc \
     brillo/url_utils.cc \
 
-libchromeos_linux_sources := \
+libbrillo_linux_sources := \
     brillo/asynchronous_signal_handler.cc \
     brillo/daemons/daemon.cc \
     brillo/file_utils.cc \
     brillo/process_reaper.cc \
 
-libchromeos_binder_sources := \
+libbrillo_binder_sources := \
     brillo/binder_watcher.cc \
 
-libchromeos_dbus_sources := \
+libbrillo_dbus_sources := \
     brillo/any.cc \
     brillo/daemons/dbus_daemon.cc \
     brillo/dbus/async_event_sequencer.cc \
@@ -58,7 +58,7 @@
     brillo/dbus/exported_property_set.cc \
     brillo/dbus/utils.cc \
 
-libchromeos_http_sources := \
+libbrillo_http_sources := \
     brillo/http/curl_api.cc \
     brillo/http/http_connection_curl.cc \
     brillo/http/http_form_data.cc \
@@ -67,11 +67,11 @@
     brillo/http/http_transport_curl.cc \
     brillo/http/http_utils.cc \
 
-libchromeos_policy_sources := \
+libbrillo_policy_sources := \
     policy/device_policy.cc \
     policy/libpolicy.cc \
 
-libchromeos_stream_sources := \
+libbrillo_stream_sources := \
     brillo/streams/file_stream.cc \
     brillo/streams/input_stream_set.cc \
     brillo/streams/memory_containers.cc \
@@ -82,13 +82,13 @@
     brillo/streams/stream_utils.cc \
     brillo/streams/tls_stream.cc \
 
-libchromeos_test_helpers_sources := \
+libbrillo_test_helpers_sources := \
     brillo/http/http_connection_fake.cc \
     brillo/http/http_transport_fake.cc \
     brillo/message_loops/fake_message_loop.cc \
     brillo/streams/fake_stream.cc \
 
-libchromeos_test_sources := \
+libbrillo_test_sources := \
     brillo/any_unittest.cc \
     brillo/any_internal_impl_unittest.cc \
     brillo/asynchronous_signal_handler_unittest.cc \
@@ -133,25 +133,25 @@
     brillo/url_utils_unittest.cc \
     brillo/variant_dictionary_unittest.cc \
 
-libchromeos_CFLAGS := -Wall \
+libbrillo_CFLAGS := -Wall \
     -Wno-char-subscripts -Wno-missing-field-initializers \
     -Wno-unused-function -Wno-unused-parameter -Werror
-libchromeos_CPPFLAGS := -Wno-non-virtual-dtor -Wno-sign-promo \
+libbrillo_CPPFLAGS := -Wno-non-virtual-dtor -Wno-sign-promo \
     -Wno-strict-aliasing
-libchromeos_includes := external/gtest/include
-libchromeos_shared_libraries := libchrome
+libbrillo_includes := external/gtest/include
+libbrillo_shared_libraries := libchrome
 
 # Shared library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos
-LOCAL_SRC_FILES := $(libchromeos_core_sources) $(libchromeos_linux_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo
+LOCAL_SRC_FILES := $(libbrillo_core_sources) $(libbrillo_linux_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries)
 LOCAL_STATIC_LIBRARIES := libmodpb64
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -160,14 +160,14 @@
 # Shared binder library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-binder
-LOCAL_SRC_FILES := $(libchromeos_binder_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) \
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-binder
+LOCAL_SRC_FILES := $(libbrillo_binder_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) \
     libbinder libutils
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -176,14 +176,14 @@
 # Shared dbus library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-dbus
-LOCAL_SRC_FILES := $(libchromeos_dbus_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos \
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-dbus
+LOCAL_SRC_FILES := $(libbrillo_dbus_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo \
     libchrome-dbus libdbus
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH) external/dbus
@@ -192,15 +192,15 @@
 # Shared minijail library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-minijail
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-minijail
 LOCAL_SRC_FILES := brillo/minijail/minijail.cc \
 
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos \
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo \
     libminijail
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -209,14 +209,14 @@
 # Shared stream library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-stream
-LOCAL_SRC_FILES := $(libchromeos_stream_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos \
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-stream
+LOCAL_SRC_FILES := $(libbrillo_stream_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo \
     libcrypto libssl
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -225,14 +225,14 @@
 # Shared http library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-http
-LOCAL_SRC_FILES := $(libchromeos_http_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos \
-    libchromeos-stream libcurl
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-http
+LOCAL_SRC_FILES := $(libbrillo_http_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo \
+    libbrillo-stream libcurl
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -241,13 +241,13 @@
 # Shared policy library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-policy
-LOCAL_SRC_FILES := $(libchromeos_policy_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries)
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-policy
+LOCAL_SRC_FILES := $(libbrillo_policy_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -256,14 +256,14 @@
 # Static library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos
-LOCAL_SRC_FILES := $(libchromeos_core_sources) $(libchromeos_linux_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo
+LOCAL_SRC_FILES := $(libbrillo_core_sources) $(libbrillo_linux_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries)
 LOCAL_STATIC_LIBRARIES := libmodpb64
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_CLANG := true
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -272,15 +272,15 @@
 # Static test-helpers library for target
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-test-helpers
-LOCAL_SRC_FILES := $(libchromeos_test_helpers_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-test-helpers
+LOCAL_SRC_FILES := $(libbrillo_test_helpers_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
 LOCAL_STATIC_LIBRARIES := libgtest libgmock
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos libcurl \
-    libchromeos-http libchromeos-stream libcrypto
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS) -Wno-sign-compare
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo libcurl \
+    libbrillo-http libbrillo-stream libcrypto
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS) -Wno-sign-compare
 LOCAL_CLANG := true
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -289,14 +289,14 @@
 # Shared library for host
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos-host
-LOCAL_SRC_FILES := $(libchromeos_core_sources)
-LOCAL_C_INCLUDES := $(libchromeos_includes)
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo-host
+LOCAL_SRC_FILES := $(libbrillo_core_sources)
+LOCAL_C_INCLUDES := $(libbrillo_includes)
 LOCAL_SHARED_LIBRARIES := libchrome-host
 LOCAL_STATIC_LIBRARIES := libmodpb64-host
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS)
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS)
 LOCAL_RTTI_FLAG := -frtti
 LOCAL_CLANG := true
 LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
@@ -305,25 +305,25 @@
 # Unit tests.
 # ========================================================
 include $(CLEAR_VARS)
-LOCAL_CPP_EXTENSION := $(libchromeos_cpp_extension)
-LOCAL_MODULE := libchromeos_test
+LOCAL_CPP_EXTENSION := $(libbrillo_cpp_extension)
+LOCAL_MODULE := libbrillo_test
 LOCAL_MODULE_CLASS := EXECUTABLES
 ifdef BRILLO
   LOCAL_MODULE_TAGS := debug
 endif
 generated_sources_dir := $(call local-generated-sources-dir)
-LOCAL_SRC_FILES := $(libchromeos_test_sources)
+LOCAL_SRC_FILES := $(libbrillo_test_sources)
 LOCAL_C_INCLUDES := \
-    $(libchromeos_includes) \
+    $(libbrillo_includes) \
     $(generated_sources_dir)/proto/external/libchromeos
 LOCAL_STATIC_LIBRARIES := libgtest libchrome_test_helpers \
-    libchromeos-test-helpers libgmock libBionicGtestMain \
+    libbrillo-test-helpers libgmock libBionicGtestMain \
     libchrome_dbus_test_helpers
-LOCAL_SHARED_LIBRARIES := $(libchromeos_shared_libraries) libchromeos libcurl \
-    libchromeos-dbus libchromeos-http libchromeos-stream libcrypto \
+LOCAL_SHARED_LIBRARIES := $(libbrillo_shared_libraries) libbrillo libcurl \
+    libbrillo-dbus libbrillo-http libbrillo-stream libcrypto \
     libchrome-dbus libdbus libprotobuf-cpp-lite-rtti
-LOCAL_CFLAGS := $(libchromeos_CFLAGS)
-LOCAL_CPPFLAGS := $(libchromeos_CPPFLAGS) -Wno-sign-compare
+LOCAL_CFLAGS := $(libbrillo_CFLAGS)
+LOCAL_CPPFLAGS := $(libbrillo_CPPFLAGS) -Wno-sign-compare
 LOCAL_CLANG := true
 LOCAL_RTTI_FLAG := -frtti
 include $(BUILD_NATIVE_TEST)
@@ -333,6 +333,6 @@
 # We su shell because process tests try setting "illegal"
 # uid/gids and expecting failures, but root can legally
 # set those to any value.
-runtargettests: libchromeos_test
+runtargettests: libbrillo_test
 	adb sync
-	adb shell su shell /data/nativetest/libchromeos_test/libchromeos_test
+	adb shell su shell /data/nativetest/libbrillo_test/libbrillo_test
diff --git a/brillo/any.h b/brillo/any.h
index 3cb2830..feedc73 100644
--- a/brillo/any.h
+++ b/brillo/any.h
@@ -20,8 +20,8 @@
 // will be std::reference_wrapper<T>. See 'References' unit tests in
 // any_unittest.cc for examples.
 
-#ifndef LIBCHROMEOS_BRILLO_ANY_H_
-#define LIBCHROMEOS_BRILLO_ANY_H_
+#ifndef LIBBRILLO_BRILLO_ANY_H_
+#define LIBBRILLO_BRILLO_ANY_H_
 
 #include <brillo/any_internal_impl.h>
 
@@ -215,4 +215,4 @@
 
 }  // namespace std
 
-#endif  // LIBCHROMEOS_BRILLO_ANY_H_
+#endif  // LIBBRILLO_BRILLO_ANY_H_
diff --git a/brillo/any_internal_impl.h b/brillo/any_internal_impl.h
index fea0aac..29126a1 100644
--- a/brillo/any_internal_impl.h
+++ b/brillo/any_internal_impl.h
@@ -4,8 +4,8 @@
 
 // Internal implementation of brillo::Any class.
 
-#ifndef LIBCHROMEOS_BRILLO_ANY_INTERNAL_IMPL_H_
-#define LIBCHROMEOS_BRILLO_ANY_INTERNAL_IMPL_H_
+#ifndef LIBBRILLO_BRILLO_ANY_INTERNAL_IMPL_H_
+#define LIBBRILLO_BRILLO_ANY_INTERNAL_IMPL_H_
 
 #include <type_traits>
 #include <typeinfo>
@@ -370,4 +370,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_ANY_INTERNAL_IMPL_H_
+#endif  // LIBBRILLO_BRILLO_ANY_INTERNAL_IMPL_H_
diff --git a/brillo/asynchronous_signal_handler.h b/brillo/asynchronous_signal_handler.h
index 8205cd6..f43b9c9 100644
--- a/brillo/asynchronous_signal_handler.h
+++ b/brillo/asynchronous_signal_handler.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
-#define LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
+#ifndef LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
+#define LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
 
 #include <signal.h>
 #include <sys/signalfd.h>
@@ -72,4 +72,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
+#endif  // LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_H_
diff --git a/brillo/asynchronous_signal_handler_interface.h b/brillo/asynchronous_signal_handler_interface.h
index 300d975..ef0012d 100644
--- a/brillo/asynchronous_signal_handler_interface.h
+++ b/brillo/asynchronous_signal_handler_interface.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
-#define LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
+#ifndef LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
+#define LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
 
 #include <sys/signalfd.h>
 
@@ -39,4 +39,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
+#endif  // LIBBRILLO_BRILLO_ASYNCHRONOUS_SIGNAL_HANDLER_INTERFACE_H_
diff --git a/brillo/backoff_entry.h b/brillo/backoff_entry.h
index ff9872b..08e1e40 100644
--- a/brillo/backoff_entry.h
+++ b/brillo/backoff_entry.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_BACKOFF_ENTRY_H_
-#define LIBCHROMEOS_BRILLO_BACKOFF_ENTRY_H_
+#ifndef LIBBRILLO_BRILLO_BACKOFF_ENTRY_H_
+#define LIBBRILLO_BRILLO_BACKOFF_ENTRY_H_
 
 #include <base/time/time.h>
 #include <brillo/brillo_export.h>
@@ -112,4 +112,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_BACKOFF_ENTRY_H_
+#endif  // LIBBRILLO_BRILLO_BACKOFF_ENTRY_H_
diff --git a/brillo/bind_lambda.h b/brillo/bind_lambda.h
index 7ae692d..687ae1a 100644
--- a/brillo/bind_lambda.h
+++ b/brillo/bind_lambda.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_BIND_LAMBDA_H_
-#define LIBCHROMEOS_BRILLO_BIND_LAMBDA_H_
+#ifndef LIBBRILLO_BRILLO_BIND_LAMBDA_H_
+#define LIBBRILLO_BRILLO_BIND_LAMBDA_H_
 
 #include <base/bind.h>
 
@@ -60,4 +60,4 @@
 }  // namespace internal
 }  // namespace base
 
-#endif  // LIBCHROMEOS_BRILLO_BIND_LAMBDA_H_
+#endif  // LIBBRILLO_BRILLO_BIND_LAMBDA_H_
diff --git a/brillo/binder_watcher.h b/brillo/binder_watcher.h
index af74f31..3683270 100644
--- a/brillo/binder_watcher.h
+++ b/brillo/binder_watcher.h
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef LIBCHROMEOS_BRILLO_BINDER_WATCHER_H_
-#define LIBCHROMEOS_BRILLO_BINDER_WATCHER_H_
+#ifndef LIBBRILLO_BRILLO_BINDER_WATCHER_H_
+#define LIBBRILLO_BRILLO_BINDER_WATCHER_H_
 
 #include <base/macros.h>
 #include <base/message_loop/message_loop.h>
@@ -44,4 +44,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_BINDER_WATCHER_H_
+#endif  // LIBBRILLO_BRILLO_BINDER_WATCHER_H_
diff --git a/brillo/brillo_export.h b/brillo/brillo_export.h
index 8d42f58..0e1f834 100644
--- a/brillo/brillo_export.h
+++ b/brillo/brillo_export.h
@@ -2,11 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_CHROMEOS_EXPORT_H_
-#define LIBCHROMEOS_BRILLO_CHROMEOS_EXPORT_H_
+#ifndef LIBBRILLO_BRILLO_BRILLO_EXPORT_H_
+#define LIBBRILLO_BRILLO_BRILLO_EXPORT_H_
 
 // Use BRILLO_EXPORT attribute to decorate your classes, methods and variables
-// that need to be exported out of libchromeos. By default, any symbol not
+// that need to be exported out of libbrillo. By default, any symbol not
 // explicitly marked with BRILLO_EXPORT attribute is not exported.
 
 // Put BRILLO_EXPORT in front of methods or variables and in between the
@@ -57,4 +57,4 @@
 // linker errors.
 #define BRILLO_PRIVATE __attribute__((__visibility__("hidden")))
 
-#endif  // LIBCHROMEOS_BRILLO_CHROMEOS_EXPORT_H_
+#endif  // LIBBRILLO_BRILLO_BRILLO_EXPORT_H_
diff --git a/brillo/cryptohome.h b/brillo/cryptohome.h
index af2097e..caca31b 100644
--- a/brillo/cryptohome.h
+++ b/brillo/cryptohome.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_CRYPTOHOME_H_
-#define LIBCHROMEOS_BRILLO_CRYPTOHOME_H_
+#ifndef LIBBRILLO_BRILLO_CRYPTOHOME_H_
+#define LIBBRILLO_BRILLO_CRYPTOHOME_H_
 
 #include <string>
 
@@ -72,4 +72,4 @@
 }  // namespace cryptohome
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_CRYPTOHOME_H_
+#endif  // LIBBRILLO_BRILLO_CRYPTOHOME_H_
diff --git a/brillo/daemons/daemon.h b/brillo/daemons/daemon.h
index e107832..46ca6d3 100644
--- a/brillo/daemons/daemon.h
+++ b/brillo/daemons/daemon.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DAEMONS_DAEMON_H_
-#define LIBCHROMEOS_BRILLO_DAEMONS_DAEMON_H_
+#ifndef LIBBRILLO_BRILLO_DAEMONS_DAEMON_H_
+#define LIBBRILLO_BRILLO_DAEMONS_DAEMON_H_
 
 #include <string>
 
@@ -113,4 +113,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DAEMONS_DAEMON_H_
+#endif  // LIBBRILLO_BRILLO_DAEMONS_DAEMON_H_
diff --git a/brillo/daemons/dbus_daemon.h b/brillo/daemons/dbus_daemon.h
index c2352c1..67124e4 100644
--- a/brillo/daemons/dbus_daemon.h
+++ b/brillo/daemons/dbus_daemon.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DAEMONS_DBUS_DAEMON_H_
-#define LIBCHROMEOS_BRILLO_DAEMONS_DBUS_DAEMON_H_
+#ifndef LIBBRILLO_BRILLO_DAEMONS_DBUS_DAEMON_H_
+#define LIBBRILLO_BRILLO_DAEMONS_DBUS_DAEMON_H_
 
 #include <memory>
 #include <string>
@@ -85,4 +85,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DAEMONS_DBUS_DAEMON_H_
+#endif  // LIBBRILLO_BRILLO_DAEMONS_DBUS_DAEMON_H_
diff --git a/brillo/data_encoding.h b/brillo/data_encoding.h
index d850f39..95d266c 100644
--- a/brillo/data_encoding.h
+++ b/brillo/data_encoding.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DATA_ENCODING_H_
-#define LIBCHROMEOS_BRILLO_DATA_ENCODING_H_
+#ifndef LIBBRILLO_BRILLO_DATA_ENCODING_H_
+#define LIBBRILLO_BRILLO_DATA_ENCODING_H_
 
 #include <string>
 #include <utility>
@@ -79,4 +79,4 @@
 }  // namespace data_encoding
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DATA_ENCODING_H_
+#endif  // LIBBRILLO_BRILLO_DATA_ENCODING_H_
diff --git a/brillo/dbus/async_event_sequencer.h b/brillo/dbus/async_event_sequencer.h
index 719c9ad..c817b55 100644
--- a/brillo/dbus/async_event_sequencer.h
+++ b/brillo/dbus/async_event_sequencer.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
+#define LIBBRILLO_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
 
 #include <set>
 #include <string>
@@ -110,4 +110,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_ASYNC_EVENT_SEQUENCER_H_
diff --git a/brillo/dbus/data_serialization.h b/brillo/dbus/data_serialization.h
index dbd96ac..3a3027e 100644
--- a/brillo/dbus/data_serialization.h
+++ b/brillo/dbus/data_serialization.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DATA_SERIALIZATION_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DATA_SERIALIZATION_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DATA_SERIALIZATION_H_
+#define LIBBRILLO_BRILLO_DBUS_DATA_SERIALIZATION_H_
 
 // The main functionality provided by this header file is methods to serialize
 // native C++ data over D-Bus. This includes three major parts:
@@ -883,4 +883,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DATA_SERIALIZATION_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DATA_SERIALIZATION_H_
diff --git a/brillo/dbus/dbus_method_invoker.h b/brillo/dbus/dbus_method_invoker.h
index df8c3c5..1b6d809 100644
--- a/brillo/dbus/dbus_method_invoker.h
+++ b/brillo/dbus/dbus_method_invoker.h
@@ -59,8 +59,8 @@
 //                                   base::Bind(OnError),
 //                                   2, 8.7);
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
 
 #include <memory>
 #include <string>
@@ -321,4 +321,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_INVOKER_H_
diff --git a/brillo/dbus/dbus_method_response.h b/brillo/dbus/dbus_method_response.h
index e30c71c..0a9ef08 100644
--- a/brillo/dbus/dbus_method_response.h
+++ b/brillo/dbus/dbus_method_response.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
 
 #include <string>
 
@@ -95,4 +95,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_METHOD_RESPONSE_H_
diff --git a/brillo/dbus/dbus_object.h b/brillo/dbus/dbus_object.h
index 1bd7ca7..6cd34dd 100644
--- a/brillo/dbus/dbus_object.h
+++ b/brillo/dbus/dbus_object.h
@@ -58,8 +58,8 @@
 };
 */
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_H_
 
 #include <map>
 #include <string>
@@ -576,4 +576,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_H_
diff --git a/brillo/dbus/dbus_object_internal_impl.h b/brillo/dbus/dbus_object_internal_impl.h
index 4ed4bb9..5f174d4 100644
--- a/brillo/dbus/dbus_object_internal_impl.h
+++ b/brillo/dbus/dbus_object_internal_impl.h
@@ -26,8 +26,8 @@
 // to the appropriate method handler using additional data captured by the
 // lambda object.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
 
 #include <memory>
 #include <string>
@@ -360,4 +360,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_INTERNAL_IMPL_H_
diff --git a/brillo/dbus/dbus_object_test_helpers.h b/brillo/dbus/dbus_object_test_helpers.h
index 6b90c5a..43c053a 100644
--- a/brillo/dbus/dbus_object_test_helpers.h
+++ b/brillo/dbus/dbus_object_test_helpers.h
@@ -9,8 +9,8 @@
 // still use DBusMethodResponse to send back the method results).
 // This file provide testing-only helpers to make calling D-Bus method handlers
 // easier.
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
 
 #include <base/bind.h>
 #include <base/memory/weak_ptr.h>
@@ -49,7 +49,7 @@
 
 // Dispatches a D-Bus method call to the corresponding handler.
 // Used mostly for testing purposes. This method is inlined so that it is
-// not included in the shipping code of libchromeos, and included at the
+// not included in the shipping code of libbrillo, and included at the
 // call sites. Returns a response from the method handler or nullptr if the
 // method hasn't provided the response message immediately
 // (i.e. it is asynchronous).
@@ -140,4 +140,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_OBJECT_TEST_HELPERS_H_
diff --git a/brillo/dbus/dbus_param_reader.h b/brillo/dbus/dbus_param_reader.h
index f72f93c..228cfb6 100644
--- a/brillo/dbus/dbus_param_reader.h
+++ b/brillo/dbus/dbus_param_reader.h
@@ -13,8 +13,8 @@
 // until there is only the return type remaining and we fall through to either
 // the void or the non-void final specialization.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_READER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_READER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_READER_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_READER_H_
 
 #include <type_traits>
 
@@ -162,4 +162,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_READER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_READER_H_
diff --git a/brillo/dbus/dbus_param_writer.h b/brillo/dbus/dbus_param_writer.h
index 3eb736e..737e425 100644
--- a/brillo/dbus/dbus_param_writer.h
+++ b/brillo/dbus/dbus_param_writer.h
@@ -11,8 +11,8 @@
 // method response message. This method skips any non-pointer parameters and
 // only appends the data for arguments that are pointers.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
 
 #include <brillo/dbus/data_serialization.h>
 #include <dbus/message.h>
@@ -77,4 +77,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_PARAM_WRITER_H_
diff --git a/brillo/dbus/dbus_property.h b/brillo/dbus/dbus_property.h
index a7b11df..01b850d 100644
--- a/brillo/dbus/dbus_property.h
+++ b/brillo/dbus/dbus_property.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_PROPERTY_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_PROPERTY_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_PROPERTY_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_PROPERTY_H_
 
 #include <brillo/dbus/data_serialization.h>
 #include <dbus/property.h>
@@ -91,4 +91,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_PROPERTY_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_PROPERTY_H_
diff --git a/brillo/dbus/dbus_service_watcher.h b/brillo/dbus/dbus_service_watcher.h
index 730f1f2..0031771 100644
--- a/brillo/dbus/dbus_service_watcher.h
+++ b/brillo/dbus/dbus_service_watcher.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
 
 #include <string>
 
@@ -50,4 +50,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_SERVICE_WATCHER_H_
diff --git a/brillo/dbus/dbus_signal.h b/brillo/dbus/dbus_signal.h
index b19f1c8..bda322a 100644
--- a/brillo/dbus/dbus_signal.h
+++ b/brillo/dbus/dbus_signal.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_H_
 
 #include <string>
 #include <typeinfo>
@@ -65,4 +65,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_H_
diff --git a/brillo/dbus/dbus_signal_handler.h b/brillo/dbus/dbus_signal_handler.h
index dfa1e78..46d7212 100644
--- a/brillo/dbus/dbus_signal_handler.h
+++ b/brillo/dbus/dbus_signal_handler.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
+#define LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
 
 #include <string>
 
@@ -65,4 +65,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_DBUS_SIGNAL_HANDLER_H_
diff --git a/brillo/dbus/exported_object_manager.h b/brillo/dbus/exported_object_manager.h
index 584c0b6..01dab5b 100644
--- a/brillo/dbus/exported_object_manager.h
+++ b/brillo/dbus/exported_object_manager.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
+#define LIBBRILLO_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
 
 #include <map>
 #include <string>
@@ -132,4 +132,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_EXPORTED_OBJECT_MANAGER_H_
diff --git a/brillo/dbus/exported_property_set.h b/brillo/dbus/exported_property_set.h
index 16f5086..f10511f 100644
--- a/brillo/dbus/exported_property_set.h
+++ b/brillo/dbus/exported_property_set.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
-#define LIBCHROMEOS_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
+#define LIBBRILLO_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
 
 #include <stdint.h>
 
@@ -223,4 +223,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_EXPORTED_PROPERTY_SET_H_
diff --git a/brillo/dbus/mock_dbus_object.h b/brillo/dbus/mock_dbus_object.h
index 75cfb71..82e2fc7 100644
--- a/brillo/dbus/mock_dbus_object.h
+++ b/brillo/dbus/mock_dbus_object.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
-#define LIBCHROMEOS_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
+#define LIBBRILLO_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
 
 #include <string>
 
@@ -29,4 +29,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_MOCK_DBUS_OBJECT_H_
diff --git a/brillo/dbus/mock_exported_object_manager.h b/brillo/dbus/mock_exported_object_manager.h
index 5a45ec3..d8abc0a 100644
--- a/brillo/dbus/mock_exported_object_manager.h
+++ b/brillo/dbus/mock_exported_object_manager.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
-#define LIBCHROMEOS_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
+#define LIBBRILLO_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
 
 #include <string>
 
@@ -39,4 +39,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_MOCK_EXPORTED_OBJECT_MANAGER_H_
diff --git a/brillo/dbus/utils.h b/brillo/dbus/utils.h
index af76ed4..a548756 100644
--- a/brillo/dbus/utils.h
+++ b/brillo/dbus/utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_DBUS_UTILS_H_
-#define LIBCHROMEOS_BRILLO_DBUS_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_DBUS_UTILS_H_
+#define LIBBRILLO_BRILLO_DBUS_UTILS_H_
 
 #include <memory>
 #include <string>
@@ -41,4 +41,4 @@
 }  // namespace dbus_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_DBUS_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_DBUS_UTILS_H_
diff --git a/brillo/errors/error.h b/brillo/errors/error.h
index 2c0f089..4cf60f5 100644
--- a/brillo/errors/error.h
+++ b/brillo/errors/error.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_ERRORS_ERROR_H_
-#define LIBCHROMEOS_BRILLO_ERRORS_ERROR_H_
+#ifndef LIBBRILLO_BRILLO_ERRORS_ERROR_H_
+#define LIBBRILLO_BRILLO_ERRORS_ERROR_H_
 
 #include <memory>
 #include <string>
@@ -126,4 +126,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_ERRORS_ERROR_H_
+#endif  // LIBBRILLO_BRILLO_ERRORS_ERROR_H_
diff --git a/brillo/errors/error_codes.h b/brillo/errors/error_codes.h
index 0189e00..a9964f6 100644
--- a/brillo/errors/error_codes.h
+++ b/brillo/errors/error_codes.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_ERRORS_ERROR_CODES_H_
-#define LIBCHROMEOS_BRILLO_ERRORS_ERROR_CODES_H_
+#ifndef LIBBRILLO_BRILLO_ERRORS_ERROR_CODES_H_
+#define LIBBRILLO_BRILLO_ERRORS_ERROR_CODES_H_
 
 #include <string>
 
@@ -40,4 +40,4 @@
 }  // namespace errors
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_ERRORS_ERROR_CODES_H_
+#endif  // LIBBRILLO_BRILLO_ERRORS_ERROR_CODES_H_
diff --git a/brillo/file_utils.h b/brillo/file_utils.h
index 968588b..60e0cdc 100644
--- a/brillo/file_utils.h
+++ b/brillo/file_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_FILE_UTILS_H_
-#define LIBCHROMEOS_BRILLO_FILE_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_FILE_UTILS_H_
+#define LIBBRILLO_BRILLO_FILE_UTILS_H_
 
 #include <sys/types.h>
 
@@ -32,4 +32,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_FILE_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_FILE_UTILS_H_
diff --git a/brillo/flag_helper.h b/brillo/flag_helper.h
index 4e770a2..47f7018 100644
--- a/brillo/flag_helper.h
+++ b/brillo/flag_helper.h
@@ -50,8 +50,8 @@
 // values passed in to the command line, Init(...) must be called after
 // all the DEFINE_xxxx macros have instantiated the variables.
 
-#ifndef LIBCHROMEOS_BRILLO_FLAG_HELPER_H_
-#define LIBCHROMEOS_BRILLO_FLAG_HELPER_H_
+#ifndef LIBBRILLO_BRILLO_FLAG_HELPER_H_
+#define LIBBRILLO_BRILLO_FLAG_HELPER_H_
 
 #include <map>
 #include <memory>
@@ -271,4 +271,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_FLAG_HELPER_H_
+#endif  // LIBBRILLO_BRILLO_FLAG_HELPER_H_
diff --git a/brillo/glib/abstract_dbus_service.h b/brillo/glib/abstract_dbus_service.h
index 8b559df..c40b658 100644
--- a/brillo/glib/abstract_dbus_service.h
+++ b/brillo/glib/abstract_dbus_service.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
-#define LIBCHROMEOS_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
+#ifndef LIBBRILLO_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
+#define LIBBRILLO_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
 
 #include <brillo/brillo_export.h>
 #include <brillo/glib/dbus.h>
@@ -47,4 +47,4 @@
 }  // namespace dbus
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
+#endif  // LIBBRILLO_BRILLO_GLIB_ABSTRACT_DBUS_SERVICE_H_
diff --git a/brillo/glib/dbus.h b/brillo/glib/dbus.h
index 73a54c9..6006009 100644
--- a/brillo/glib/dbus.h
+++ b/brillo/glib/dbus.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_GLIB_DBUS_H_
-#define LIBCHROMEOS_BRILLO_GLIB_DBUS_H_
+#ifndef LIBBRILLO_BRILLO_GLIB_DBUS_H_
+#define LIBBRILLO_BRILLO_GLIB_DBUS_H_
 
 #include <dbus/dbus-glib.h>
 #include <glib-object.h>
@@ -465,4 +465,4 @@
 }  // namespace dbus
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_GLIB_DBUS_H_
+#endif  // LIBBRILLO_BRILLO_GLIB_DBUS_H_
diff --git a/brillo/glib/object.h b/brillo/glib/object.h
index c4dc58d..b9f2079 100644
--- a/brillo/glib/object.h
+++ b/brillo/glib/object.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_GLIB_OBJECT_H_
-#define LIBCHROMEOS_BRILLO_GLIB_OBJECT_H_
+#ifndef LIBBRILLO_BRILLO_GLIB_OBJECT_H_
+#define LIBBRILLO_BRILLO_GLIB_OBJECT_H_
 
 #include <glib-object.h>
 #include <stdint.h>
@@ -505,4 +505,4 @@
 }  // namespace glib
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_GLIB_OBJECT_H_
+#endif  // LIBBRILLO_BRILLO_GLIB_OBJECT_H_
diff --git a/brillo/http/curl_api.h b/brillo/http/curl_api.h
index 5c18158..ac4c0ea 100644
--- a/brillo/http/curl_api.h
+++ b/brillo/http/curl_api.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_CURL_API_H_
-#define LIBCHROMEOS_BRILLO_HTTP_CURL_API_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_CURL_API_H_
+#define LIBBRILLO_BRILLO_HTTP_CURL_API_H_
 
 #include <curl/curl.h>
 
@@ -207,4 +207,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_CURL_API_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_CURL_API_H_
diff --git a/brillo/http/http_connection.h b/brillo/http/http_connection.h
index 44d3ccb..9150929 100644
--- a/brillo/http/http_connection.h
+++ b/brillo/http/http_connection.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_H_
 
 #include <memory>
 #include <string>
@@ -105,4 +105,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_H_
diff --git a/brillo/http/http_connection_curl.h b/brillo/http/http_connection_curl.h
index f173025..c34de57 100644
--- a/brillo/http/http_connection_curl.h
+++ b/brillo/http/http_connection_curl.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
 
 #include <map>
 #include <string>
@@ -100,4 +100,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_CURL_H_
diff --git a/brillo/http/http_connection_fake.h b/brillo/http/http_connection_fake.h
index cc05fbd..f880b25 100644
--- a/brillo/http/http_connection_fake.h
+++ b/brillo/http/http_connection_fake.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
 
 #include <map>
 #include <string>
@@ -59,4 +59,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_CONNECTION_FAKE_H_
diff --git a/brillo/http/http_form_data.h b/brillo/http/http_form_data.h
index 8bbc946..55ec150 100644
--- a/brillo/http/http_form_data.h
+++ b/brillo/http/http_form_data.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_FORM_DATA_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_FORM_DATA_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_FORM_DATA_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_FORM_DATA_H_
 
 #include <memory>
 #include <string>
@@ -230,4 +230,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_FORM_DATA_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_FORM_DATA_H_
diff --git a/brillo/http/http_request.h b/brillo/http/http_request.h
index b47a50c..42d8048 100644
--- a/brillo/http/http_request.h
+++ b/brillo/http/http_request.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_REQUEST_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_REQUEST_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_REQUEST_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_REQUEST_H_
 
 #include <limits>
 #include <map>
@@ -378,4 +378,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_REQUEST_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_REQUEST_H_
diff --git a/brillo/http/http_transport.h b/brillo/http/http_transport.h
index 5b56b5c..63e135c 100644
--- a/brillo/http/http_transport.h
+++ b/brillo/http/http_transport.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_H_
 
 #include <memory>
 #include <string>
@@ -92,4 +92,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_H_
diff --git a/brillo/http/http_transport_curl.h b/brillo/http/http_transport_curl.h
index e07f56f..0a95c63 100644
--- a/brillo/http/http_transport_curl.h
+++ b/brillo/http/http_transport_curl.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
 
 #include <map>
 #include <string>
@@ -137,4 +137,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_CURL_H_
diff --git a/brillo/http/http_transport_fake.h b/brillo/http/http_transport_fake.h
index 3d6aecb..ac8bc2a 100644
--- a/brillo/http/http_transport_fake.h
+++ b/brillo/http/http_transport_fake.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
 
 #include <map>
 #include <queue>
@@ -262,4 +262,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_TRANSPORT_FAKE_H_
diff --git a/brillo/http/http_utils.h b/brillo/http/http_utils.h
index 7d5f937..e09bab8 100644
--- a/brillo/http/http_utils.h
+++ b/brillo/http/http_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_HTTP_UTILS_H_
-#define LIBCHROMEOS_BRILLO_HTTP_HTTP_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_HTTP_UTILS_H_
+#define LIBBRILLO_BRILLO_HTTP_HTTP_UTILS_H_
 
 #include <string>
 #include <utility>
@@ -316,4 +316,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_HTTP_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_HTTP_UTILS_H_
diff --git a/brillo/http/mock_connection.h b/brillo/http/mock_connection.h
index c57aac1..0796a7e 100644
--- a/brillo/http/mock_connection.h
+++ b/brillo/http/mock_connection.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_MOCK_CONNECTION_H_
-#define LIBCHROMEOS_BRILLO_HTTP_MOCK_CONNECTION_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_MOCK_CONNECTION_H_
+#define LIBBRILLO_BRILLO_HTTP_MOCK_CONNECTION_H_
 
 #include <memory>
 #include <string>
@@ -48,4 +48,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_MOCK_CONNECTION_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_MOCK_CONNECTION_H_
diff --git a/brillo/http/mock_curl_api.h b/brillo/http/mock_curl_api.h
index 838ebf2..2dd9d04 100644
--- a/brillo/http/mock_curl_api.h
+++ b/brillo/http/mock_curl_api.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_MOCK_CURL_API_H_
-#define LIBCHROMEOS_BRILLO_HTTP_MOCK_CURL_API_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_MOCK_CURL_API_H_
+#define LIBBRILLO_BRILLO_HTTP_MOCK_CURL_API_H_
 
 #include <string>
 
@@ -53,4 +53,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_MOCK_CURL_API_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_MOCK_CURL_API_H_
diff --git a/brillo/http/mock_transport.h b/brillo/http/mock_transport.h
index bba1708..9bc6c14 100644
--- a/brillo/http/mock_transport.h
+++ b/brillo/http/mock_transport.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_HTTP_MOCK_TRANSPORT_H_
-#define LIBCHROMEOS_BRILLO_HTTP_MOCK_TRANSPORT_H_
+#ifndef LIBBRILLO_BRILLO_HTTP_MOCK_TRANSPORT_H_
+#define LIBBRILLO_BRILLO_HTTP_MOCK_TRANSPORT_H_
 
 #include <memory>
 #include <string>
@@ -41,4 +41,4 @@
 }  // namespace http
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_HTTP_MOCK_TRANSPORT_H_
+#endif  // LIBBRILLO_BRILLO_HTTP_MOCK_TRANSPORT_H_
diff --git a/brillo/key_value_store.h b/brillo/key_value_store.h
index 0511326..cc5fa40 100644
--- a/brillo/key_value_store.h
+++ b/brillo/key_value_store.h
@@ -6,8 +6,8 @@
 // key value store. Each key/value pair is stored on its own line and
 // separated by the first '=' on the line.
 
-#ifndef LIBCHROMEOS_BRILLO_KEY_VALUE_STORE_H_
-#define LIBCHROMEOS_BRILLO_KEY_VALUE_STORE_H_
+#ifndef LIBBRILLO_BRILLO_KEY_VALUE_STORE_H_
+#define LIBBRILLO_BRILLO_KEY_VALUE_STORE_H_
 
 #include <map>
 #include <string>
@@ -73,4 +73,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_KEY_VALUE_STORE_H_
+#endif  // LIBBRILLO_BRILLO_KEY_VALUE_STORE_H_
diff --git a/brillo/location_logging.h b/brillo/location_logging.h
index 011d1e2..bc3baf0 100644
--- a/brillo/location_logging.h
+++ b/brillo/location_logging.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_LOCATION_LOGGING_H_
-#define LIBCHROMEOS_BRILLO_LOCATION_LOGGING_H_
+#ifndef LIBBRILLO_BRILLO_LOCATION_LOGGING_H_
+#define LIBBRILLO_BRILLO_LOCATION_LOGGING_H_
 
 // These macros help to log Location objects in verbose mode.
 
@@ -21,4 +21,4 @@
   LAZY_STREAM(VLOG_LOC_STREAM(from_here, verbose_level),                \
               ::logging::DEBUG_MODE && VLOG_IS_ON(verbose_level))
 
-#endif  // LIBCHROMEOS_BRILLO_LOCATION_LOGGING_H_
+#endif  // LIBBRILLO_BRILLO_LOCATION_LOGGING_H_
diff --git a/brillo/make_unique_ptr.h b/brillo/make_unique_ptr.h
index 35b135e..89f56e6 100644
--- a/brillo/make_unique_ptr.h
+++ b/brillo/make_unique_ptr.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MAKE_UNIQUE_PTR_H_
-#define LIBCHROMEOS_BRILLO_MAKE_UNIQUE_PTR_H_
+#ifndef LIBBRILLO_BRILLO_MAKE_UNIQUE_PTR_H_
+#define LIBBRILLO_BRILLO_MAKE_UNIQUE_PTR_H_
 
 #include <memory>
 
@@ -22,4 +22,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MAKE_UNIQUE_PTR_H_
+#endif  // LIBBRILLO_BRILLO_MAKE_UNIQUE_PTR_H_
diff --git a/brillo/map_utils.h b/brillo/map_utils.h
index b7f1658..a4568f3 100644
--- a/brillo/map_utils.h
+++ b/brillo/map_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MAP_UTILS_H_
-#define LIBCHROMEOS_BRILLO_MAP_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_MAP_UTILS_H_
+#define LIBBRILLO_BRILLO_MAP_UTILS_H_
 
 #include <map>
 #include <set>
@@ -68,4 +68,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MAP_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_MAP_UTILS_H_
diff --git a/brillo/message_loops/base_message_loop.h b/brillo/message_loops/base_message_loop.h
index 76bd94a..529d476 100644
--- a/brillo/message_loops/base_message_loop.h
+++ b/brillo/message_loops/base_message_loop.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
 
 // BaseMessageLoop is a brillo::MessageLoop implementation based on
 // base::MessageLoopForIO. This allows to mix new code using
@@ -152,4 +152,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_BASE_MESSAGE_LOOP_H_
diff --git a/brillo/message_loops/fake_message_loop.h b/brillo/message_loops/fake_message_loop.h
index 043152b..c8c1313 100644
--- a/brillo/message_loops/fake_message_loop.h
+++ b/brillo/message_loops/fake_message_loop.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
 
 #include <functional>
 #include <map>
@@ -96,4 +96,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_FAKE_MESSAGE_LOOP_H_
diff --git a/brillo/message_loops/glib_message_loop.h b/brillo/message_loops/glib_message_loop.h
index 1bebc23..50fe2ce 100644
--- a/brillo/message_loops/glib_message_loop.h
+++ b/brillo/message_loops/glib_message_loop.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
 
 #include <map>
 #include <memory>
@@ -80,4 +80,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_GLIB_MESSAGE_LOOP_H_
diff --git a/brillo/message_loops/message_loop.h b/brillo/message_loops/message_loop.h
index 4ffce02..c7e3586 100644
--- a/brillo/message_loops/message_loop.h
+++ b/brillo/message_loops/message_loop.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
 
 #include <string>
 
@@ -132,4 +132,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_H_
diff --git a/brillo/message_loops/message_loop_utils.h b/brillo/message_loops/message_loop_utils.h
index b7338fd..d49ebdf 100644
--- a/brillo/message_loops/message_loop_utils.h
+++ b/brillo/message_loops/message_loop_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
 
 #include <base/callback.h>
 #include <base/time/time.h>
@@ -27,4 +27,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_MESSAGE_LOOP_UTILS_H_
diff --git a/brillo/message_loops/mock_message_loop.h b/brillo/message_loops/mock_message_loop.h
index 73fbe8d..71632f2 100644
--- a/brillo/message_loops/mock_message_loop.h
+++ b/brillo/message_loops/mock_message_loop.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
-#define LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
+#ifndef LIBBRILLO_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
+#define LIBBRILLO_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
 
 #include <gmock/gmock.h>
 
@@ -86,4 +86,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
+#endif  // LIBBRILLO_BRILLO_MESSAGE_LOOPS_MOCK_MESSAGE_LOOP_H_
diff --git a/brillo/mime_utils.h b/brillo/mime_utils.h
index 9e05460..869b19e 100644
--- a/brillo/mime_utils.h
+++ b/brillo/mime_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MIME_UTILS_H_
-#define LIBCHROMEOS_BRILLO_MIME_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_MIME_UTILS_H_
+#define LIBBRILLO_BRILLO_MIME_UTILS_H_
 
 #include <string>
 #include <utility>
@@ -123,4 +123,4 @@
 }  // namespace mime
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MIME_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_MIME_UTILS_H_
diff --git a/brillo/minijail/minijail.h b/brillo/minijail/minijail.h
index eaa85a8..271971d 100644
--- a/brillo/minijail/minijail.h
+++ b/brillo/minijail/minijail.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MINIJAIL_MINIJAIL_H_
-#define LIBCHROMEOS_BRILLO_MINIJAIL_MINIJAIL_H_
+#ifndef LIBBRILLO_BRILLO_MINIJAIL_MINIJAIL_H_
+#define LIBBRILLO_BRILLO_MINIJAIL_MINIJAIL_H_
 
 #include <vector>
 
@@ -112,4 +112,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MINIJAIL_MINIJAIL_H_
+#endif  // LIBBRILLO_BRILLO_MINIJAIL_MINIJAIL_H_
diff --git a/brillo/minijail/mock_minijail.h b/brillo/minijail/mock_minijail.h
index 8eb209f..b09cd80 100644
--- a/brillo/minijail/mock_minijail.h
+++ b/brillo/minijail/mock_minijail.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
-#define LIBCHROMEOS_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
+#ifndef LIBBRILLO_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
+#define LIBBRILLO_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
 
 #include <vector>
 
@@ -64,4 +64,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
+#endif  // LIBBRILLO_BRILLO_MINIJAIL_MOCK_MINIJAIL_H_
diff --git a/brillo/osrelease_reader.h b/brillo/osrelease_reader.h
index b72f733..f29c14d 100644
--- a/brillo/osrelease_reader.h
+++ b/brillo/osrelease_reader.h
@@ -6,8 +6,8 @@
 // Standard fields can come from both places depending on how we set them. They
 // should always be accessed through this interface.
 
-#ifndef LIBCHROMEOS_BRILLO_OSRELEASE_READER_H_
-#define LIBCHROMEOS_BRILLO_OSRELEASE_READER_H_
+#ifndef LIBBRILLO_BRILLO_OSRELEASE_READER_H_
+#define LIBBRILLO_BRILLO_OSRELEASE_READER_H_
 
 #include <string>
 
@@ -51,4 +51,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_OSRELEASE_READER_H_
+#endif  // LIBBRILLO_BRILLO_OSRELEASE_READER_H_
diff --git a/brillo/pointer_utils.h b/brillo/pointer_utils.h
index 1cee1f8..f688fa8 100644
--- a/brillo/pointer_utils.h
+++ b/brillo/pointer_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_POINTER_UTILS_H_
-#define LIBCHROMEOS_BRILLO_POINTER_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_POINTER_UTILS_H_
+#define LIBBRILLO_BRILLO_POINTER_UTILS_H_
 
 #include <cstdint>
 #include <sys/types.h>
@@ -21,4 +21,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_POINTER_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_POINTER_UTILS_H_
diff --git a/brillo/process.h b/brillo/process.h
index 568e8e0..d527d76 100644
--- a/brillo/process.h
+++ b/brillo/process.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_PROCESS_H_
-#define LIBCHROMEOS_BRILLO_PROCESS_H_
+#ifndef LIBBRILLO_BRILLO_PROCESS_H_
+#define LIBBRILLO_BRILLO_PROCESS_H_
 
 #include <sys/types.h>
 
@@ -197,4 +197,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_PROCESS_H_
+#endif  // LIBBRILLO_BRILLO_PROCESS_H_
diff --git a/brillo/process_information.h b/brillo/process_information.h
index 8bdcf43..3f0a2c9 100644
--- a/brillo/process_information.h
+++ b/brillo/process_information.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_PROCESS_INFORMATION_H_
-#define LIBCHROMEOS_BRILLO_PROCESS_INFORMATION_H_
+#ifndef LIBBRILLO_BRILLO_PROCESS_INFORMATION_H_
+#define LIBBRILLO_BRILLO_PROCESS_INFORMATION_H_
 
 #include <set>
 #include <string>
@@ -62,4 +62,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_PROCESS_INFORMATION_H_
+#endif  // LIBBRILLO_BRILLO_PROCESS_INFORMATION_H_
diff --git a/brillo/process_mock.h b/brillo/process_mock.h
index 88b60c6..c89fefe 100644
--- a/brillo/process_mock.h
+++ b/brillo/process_mock.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_PROCESS_MOCK_H_
-#define LIBCHROMEOS_BRILLO_PROCESS_MOCK_H_
+#ifndef LIBBRILLO_BRILLO_PROCESS_MOCK_H_
+#define LIBBRILLO_BRILLO_PROCESS_MOCK_H_
 
 #include <string>
 
@@ -40,4 +40,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_PROCESS_MOCK_H_
+#endif  // LIBBRILLO_BRILLO_PROCESS_MOCK_H_
diff --git a/brillo/process_reaper.h b/brillo/process_reaper.h
index 4d28f4e..d88f572 100644
--- a/brillo/process_reaper.h
+++ b/brillo/process_reaper.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_PROCESS_REAPER_H_
-#define LIBCHROMEOS_BRILLO_PROCESS_REAPER_H_
+#ifndef LIBBRILLO_BRILLO_PROCESS_REAPER_H_
+#define LIBBRILLO_BRILLO_PROCESS_REAPER_H_
 
 #include <sys/wait.h>
 
@@ -64,4 +64,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_PROCESS_REAPER_H_
+#endif  // LIBBRILLO_BRILLO_PROCESS_REAPER_H_
diff --git a/brillo/secure_blob.h b/brillo/secure_blob.h
index dec9444..b6111c7 100644
--- a/brillo/secure_blob.h
+++ b/brillo/secure_blob.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_SECURE_BLOB_H_
-#define LIBCHROMEOS_BRILLO_SECURE_BLOB_H_
+#ifndef LIBBRILLO_BRILLO_SECURE_BLOB_H_
+#define LIBBRILLO_BRILLO_SECURE_BLOB_H_
 
 #include <string>
 #include <vector>
@@ -55,4 +55,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_SECURE_BLOB_H_
+#endif  // LIBBRILLO_BRILLO_SECURE_BLOB_H_
diff --git a/brillo/streams/fake_stream.h b/brillo/streams/fake_stream.h
index 2943a44..fb9b522 100644
--- a/brillo/streams/fake_stream.h
+++ b/brillo/streams/fake_stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_FAKE_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_FAKE_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_FAKE_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_FAKE_STREAM_H_
 
 #include <queue>
 #include <string>
@@ -168,4 +168,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_FAKE_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_FAKE_STREAM_H_
diff --git a/brillo/streams/file_stream.h b/brillo/streams/file_stream.h
index 002a850..1cf39b5 100644
--- a/brillo/streams/file_stream.h
+++ b/brillo/streams/file_stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_FILE_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_FILE_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_FILE_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_FILE_STREAM_H_
 
 #include <base/files/file_path.h>
 #include <base/macros.h>
@@ -172,4 +172,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_FILE_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_FILE_STREAM_H_
diff --git a/brillo/streams/input_stream_set.h b/brillo/streams/input_stream_set.h
index fda255f..8770b10 100644
--- a/brillo/streams/input_stream_set.h
+++ b/brillo/streams/input_stream_set.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_INPUT_STREAM_SET_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_INPUT_STREAM_SET_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_INPUT_STREAM_SET_H_
+#define LIBBRILLO_BRILLO_STREAMS_INPUT_STREAM_SET_H_
 
 #include <vector>
 
@@ -129,4 +129,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_INPUT_STREAM_SET_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_INPUT_STREAM_SET_H_
diff --git a/brillo/streams/memory_containers.h b/brillo/streams/memory_containers.h
index 498401e..ba2ebc4 100644
--- a/brillo/streams/memory_containers.h
+++ b/brillo/streams/memory_containers.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
+#define LIBBRILLO_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
 
 #include <string>
 #include <vector>
@@ -281,4 +281,4 @@
 }  // namespace data_container
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_MEMORY_CONTAINERS_H_
diff --git a/brillo/streams/memory_stream.h b/brillo/streams/memory_stream.h
index b9f5e4b..b4927a8 100644
--- a/brillo/streams/memory_stream.h
+++ b/brillo/streams/memory_stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_MEMORY_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_MEMORY_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_MEMORY_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_MEMORY_STREAM_H_
 
 #include <string>
 #include <vector>
@@ -209,4 +209,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_MEMORY_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_MEMORY_STREAM_H_
diff --git a/brillo/streams/mock_stream.h b/brillo/streams/mock_stream.h
index 4289cc0..934912a 100644
--- a/brillo/streams/mock_stream.h
+++ b/brillo/streams/mock_stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_MOCK_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_MOCK_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_MOCK_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_MOCK_STREAM_H_
 
 #include <gmock/gmock.h>
 
@@ -72,4 +72,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_MOCK_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_MOCK_STREAM_H_
diff --git a/brillo/streams/openssl_stream_bio.h b/brillo/streams/openssl_stream_bio.h
index 3cb0989..549c99c 100644
--- a/brillo/streams/openssl_stream_bio.h
+++ b/brillo/streams/openssl_stream_bio.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
+#define LIBBRILLO_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
 
 #include <brillo/brillo_export.h>
 
@@ -24,4 +24,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_OPENSSL_STREAM_BIO_H_
diff --git a/brillo/streams/stream.h b/brillo/streams/stream.h
index 6614cb3..d7c58db 100644
--- a/brillo/streams/stream.h
+++ b/brillo/streams/stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_STREAM_H_
 
 #include <cstdint>
 #include <memory>
@@ -503,4 +503,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_STREAM_H_
diff --git a/brillo/streams/stream_errors.h b/brillo/streams/stream_errors.h
index 564d097..1eacc5e 100644
--- a/brillo/streams/stream_errors.h
+++ b/brillo/streams/stream_errors.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_STREAM_ERRORS_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_STREAM_ERRORS_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_STREAM_ERRORS_H_
+#define LIBBRILLO_BRILLO_STREAMS_STREAM_ERRORS_H_
 
 #include <brillo/brillo_export.h>
 
@@ -24,4 +24,4 @@
 }  // namespace errors
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_STREAM_ERRORS_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_STREAM_ERRORS_H_
diff --git a/brillo/streams/stream_utils.h b/brillo/streams/stream_utils.h
index 84792ce..981a6d5 100644
--- a/brillo/streams/stream_utils.h
+++ b/brillo/streams/stream_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_STREAM_UTILS_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_STREAM_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_STREAM_UTILS_H_
+#define LIBBRILLO_BRILLO_STREAMS_STREAM_UTILS_H_
 
 #include <base/location.h>
 #include <brillo/brillo_export.h>
@@ -111,4 +111,4 @@
 }  // namespace stream_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_STREAM_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_STREAM_UTILS_H_
diff --git a/brillo/streams/tls_stream.h b/brillo/streams/tls_stream.h
index 5513eb5..1431eec 100644
--- a/brillo/streams/tls_stream.h
+++ b/brillo/streams/tls_stream.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STREAMS_TLS_STREAM_H_
-#define LIBCHROMEOS_BRILLO_STREAMS_TLS_STREAM_H_
+#ifndef LIBBRILLO_BRILLO_STREAMS_TLS_STREAM_H_
+#define LIBBRILLO_BRILLO_STREAMS_TLS_STREAM_H_
 
 #include <memory>
 #include <string>
@@ -81,4 +81,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STREAMS_TLS_STREAM_H_
+#endif  // LIBBRILLO_BRILLO_STREAMS_TLS_STREAM_H_
diff --git a/brillo/strings/string_utils.h b/brillo/strings/string_utils.h
index f467bf9..6f1a934 100644
--- a/brillo/strings/string_utils.h
+++ b/brillo/strings/string_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_STRINGS_STRING_UTILS_H_
-#define LIBCHROMEOS_BRILLO_STRINGS_STRING_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_STRINGS_STRING_UTILS_H_
+#define LIBBRILLO_BRILLO_STRINGS_STRING_UTILS_H_
 
 #include <string>
 #include <utility>
@@ -128,4 +128,4 @@
 }  // namespace string_utils
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_STRINGS_STRING_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_STRINGS_STRING_UTILS_H_
diff --git a/brillo/syslog_logging.h b/brillo/syslog_logging.h
index d940b42..b054259 100644
--- a/brillo/syslog_logging.h
+++ b/brillo/syslog_logging.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_SYSLOG_LOGGING_H_
-#define LIBCHROMEOS_BRILLO_SYSLOG_LOGGING_H_
+#ifndef LIBBRILLO_BRILLO_SYSLOG_LOGGING_H_
+#define LIBBRILLO_BRILLO_SYSLOG_LOGGING_H_
 
 #include <string>
 
@@ -45,4 +45,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_SYSLOG_LOGGING_H_
+#endif  // LIBBRILLO_BRILLO_SYSLOG_LOGGING_H_
diff --git a/brillo/test_helpers.h b/brillo/test_helpers.h
index f035b66..815eede 100644
--- a/brillo/test_helpers.h
+++ b/brillo/test_helpers.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_TEST_HELPERS_H_
-#define LIBCHROMEOS_BRILLO_TEST_HELPERS_H_
+#ifndef LIBBRILLO_BRILLO_TEST_HELPERS_H_
+#define LIBBRILLO_BRILLO_TEST_HELPERS_H_
 
 #include "gtest/gtest.h"
 
@@ -29,4 +29,4 @@
   ::testing::InitGoogleTest(argc, argv);
 }
 
-#endif  // LIBCHROMEOS_BRILLO_TEST_HELPERS_H_
+#endif  // LIBBRILLO_BRILLO_TEST_HELPERS_H_
diff --git a/brillo/type_name_undecorate.h b/brillo/type_name_undecorate.h
index 2da657c..8cf9030 100644
--- a/brillo/type_name_undecorate.h
+++ b/brillo/type_name_undecorate.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_TYPE_NAME_UNDECORATE_H_
-#define LIBCHROMEOS_BRILLO_TYPE_NAME_UNDECORATE_H_
+#ifndef LIBBRILLO_BRILLO_TYPE_NAME_UNDECORATE_H_
+#define LIBBRILLO_BRILLO_TYPE_NAME_UNDECORATE_H_
 
 #include <string>
 #include <typeinfo>
@@ -24,4 +24,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_TYPE_NAME_UNDECORATE_H_
+#endif  // LIBBRILLO_BRILLO_TYPE_NAME_UNDECORATE_H_
diff --git a/brillo/url_utils.h b/brillo/url_utils.h
index 80dea5a..fd66dd6 100644
--- a/brillo/url_utils.h
+++ b/brillo/url_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_URL_UTILS_H_
-#define LIBCHROMEOS_BRILLO_URL_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_URL_UTILS_H_
+#define LIBBRILLO_BRILLO_URL_UTILS_H_
 
 #include <string>
 #include <vector>
@@ -82,4 +82,4 @@
 }  // namespace url
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_URL_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_URL_UTILS_H_
diff --git a/brillo/userdb_utils.h b/brillo/userdb_utils.h
index 4377119..8d6dc20 100644
--- a/brillo/userdb_utils.h
+++ b/brillo/userdb_utils.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_USERDB_UTILS_H_
-#define LIBCHROMEOS_BRILLO_USERDB_UTILS_H_
+#ifndef LIBBRILLO_BRILLO_USERDB_UTILS_H_
+#define LIBBRILLO_BRILLO_USERDB_UTILS_H_
 
 #include <sys/types.h>
 
@@ -29,4 +29,4 @@
 }  // namespace userdb
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_USERDB_UTILS_H_
+#endif  // LIBBRILLO_BRILLO_USERDB_UTILS_H_
diff --git a/brillo/variant_dictionary.h b/brillo/variant_dictionary.h
index c934455..0b71e9c 100644
--- a/brillo/variant_dictionary.h
+++ b/brillo/variant_dictionary.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_BRILLO_VARIANT_DICTIONARY_H_
-#define LIBCHROMEOS_BRILLO_VARIANT_DICTIONARY_H_
+#ifndef LIBBRILLO_BRILLO_VARIANT_DICTIONARY_H_
+#define LIBBRILLO_BRILLO_VARIANT_DICTIONARY_H_
 
 #include <map>
 #include <string>
@@ -30,4 +30,4 @@
 
 }  // namespace brillo
 
-#endif  // LIBCHROMEOS_BRILLO_VARIANT_DICTIONARY_H_
+#endif  // LIBBRILLO_BRILLO_VARIANT_DICTIONARY_H_
diff --git a/libchromeos-334380.gypi b/libbrillo-334380.gypi
similarity index 65%
rename from libchromeos-334380.gypi
rename to libbrillo-334380.gypi
index 7fb70f4..5e0d8ce 100644
--- a/libchromeos-334380.gypi
+++ b/libbrillo-334380.gypi
@@ -3,6 +3,6 @@
     'libbase_ver': 334380,
   },
   'includes': [
-    '../libchromeos/libchromeos.gypi',
+    '../libbrillo/libbrillo.gypi',
   ],
 }
diff --git a/libbrillo-glib.pc.in b/libbrillo-glib.pc.in
new file mode 100644
index 0000000..cfd9fc8
--- /dev/null
+++ b/libbrillo-glib.pc.in
@@ -0,0 +1,8 @@
+bslot=@BSLOT@
+
+Name: libbrillo-glib
+Description: brillo glib wrapper library
+Version: ${bslot}
+Requires.private: @PRIVATE_PC@
+Libs: -lbrillo-glib-${bslot}
+
diff --git a/libbrillo-test.pc.in b/libbrillo-test.pc.in
new file mode 100644
index 0000000..4fece7c
--- /dev/null
+++ b/libbrillo-test.pc.in
@@ -0,0 +1,8 @@
+bslot=@BSLOT@
+
+Name: libbrillo-test
+Description: brillo test library
+Version: ${bslot}
+# Because libbrillo-test is static, we have to depend directly on everything.
+Requires: @PRIVATE_PC@
+Libs: -lbrillo-test-${bslot}
diff --git a/libbrillo.gyp b/libbrillo.gyp
new file mode 100644
index 0000000..4a03539
--- /dev/null
+++ b/libbrillo.gyp
@@ -0,0 +1,6 @@
+{
+  'includes': [
+    'libbrillo-334380.gypi',
+    'libpolicy.gypi',
+  ]
+}
diff --git a/libchromeos.gypi b/libbrillo.gypi
similarity index 88%
rename from libchromeos.gypi
rename to libbrillo.gypi
index 4bf5a5d..e90252b 100644
--- a/libchromeos.gypi
+++ b/libbrillo.gypi
@@ -6,30 +6,30 @@
       ],
     },
     'include_dirs': [
-      '../libchromeos',
+      '../libbrillo',
     ],
   },
   'targets': [
     {
-      'target_name': 'libchromeos-<(libbase_ver)',
+      'target_name': 'libbrillo-<(libbase_ver)',
       'type': 'none',
       'dependencies': [
-        'libchromeos-core-<(libbase_ver)',
-        'libchromeos-cryptohome-<(libbase_ver)',
-        'libchromeos-http-<(libbase_ver)',
-        'libchromeos-minijail-<(libbase_ver)',
-        'libchromeos-streams-<(libbase_ver)',
+        'libbrillo-core-<(libbase_ver)',
+        'libbrillo-cryptohome-<(libbase_ver)',
+        'libbrillo-http-<(libbase_ver)',
+        'libbrillo-minijail-<(libbase_ver)',
+        'libbrillo-streams-<(libbase_ver)',
         'libpolicy-<(libbase_ver)',
       ],
       'direct_dependent_settings': {
         'include_dirs': [
-          '../libchromeos',
+          '../libbrillo',
         ],
       },
       'includes': ['../common-mk/deps.gypi'],
     },
     {
-      'target_name': 'libchromeos-core-<(libbase_ver)',
+      'target_name': 'libbrillo-core-<(libbase_ver)',
       'type': 'shared_library',
       'variables': {
         'exported_deps': [
@@ -84,11 +84,11 @@
       ],
     },
     {
-      'target_name': 'libchromeos-http-<(libbase_ver)',
+      'target_name': 'libbrillo-http-<(libbase_ver)',
       'type': 'shared_library',
       'dependencies': [
-        'libchromeos-core-<(libbase_ver)',
-        'libchromeos-streams-<(libbase_ver)',
+        'libbrillo-core-<(libbase_ver)',
+        'libbrillo-streams-<(libbase_ver)',
       ],
       'variables': {
         'exported_deps': [
@@ -114,10 +114,10 @@
       ],
     },
     {
-      'target_name': 'libchromeos-streams-<(libbase_ver)',
+      'target_name': 'libbrillo-streams-<(libbase_ver)',
       'type': 'shared_library',
       'dependencies': [
-        'libchromeos-core-<(libbase_ver)',
+        'libbrillo-core-<(libbase_ver)',
       ],
       'variables': {
         'exported_deps': [
@@ -145,11 +145,11 @@
       ],
     },
     {
-      'target_name': 'libchromeos-test-<(libbase_ver)',
+      'target_name': 'libbrillo-test-<(libbase_ver)',
       'type': 'static_library',
       'standalone_static_library': 1,
       'dependencies': [
-        'libchromeos-http-<(libbase_ver)',
+        'libbrillo-http-<(libbase_ver)',
       ],
       'sources': [
         'brillo/http/http_connection_fake.cc',
@@ -160,7 +160,7 @@
       'includes': ['../common-mk/deps.gypi'],
     },
     {
-      'target_name': 'libchromeos-cryptohome-<(libbase_ver)',
+      'target_name': 'libbrillo-cryptohome-<(libbase_ver)',
       'type': 'shared_library',
       'variables': {
         'exported_deps': [
@@ -180,7 +180,7 @@
       ],
     },
     {
-      'target_name': 'libchromeos-minijail-<(libbase_ver)',
+      'target_name': 'libbrillo-minijail-<(libbase_ver)',
       'type': 'shared_library',
       'variables': {
         'exported_deps': [
@@ -224,7 +224,7 @@
         },
       },
       'ldflags': [
-        '-Wl,--version-script,<(platform2_root)/libchromeos/libpolicy.ver',
+        '-Wl,--version-script,<(platform2_root)/libbrillo/libpolicy.ver',
       ],
       'sources': [
         'policy/device_policy.cc',
@@ -233,10 +233,10 @@
       ],
     },
     {
-      'target_name': 'libchromeos-glib-<(libbase_ver)',
+      'target_name': 'libbrillo-glib-<(libbase_ver)',
       'type': 'shared_library',
       'dependencies': [
-          'libchromeos-<(libbase_ver)',
+          'libbrillo-<(libbase_ver)',
       ],
       'variables': {
         'exported_deps': [
@@ -270,12 +270,12 @@
     ['USE_test == 1', {
       'targets': [
         {
-          'target_name': 'libchromeos-<(libbase_ver)_unittests',
+          'target_name': 'libbrillo-<(libbase_ver)_unittests',
           'type': 'executable',
           'dependencies': [
-            'libchromeos-<(libbase_ver)',
-            'libchromeos-test-<(libbase_ver)',
-            'libchromeos-glib-<(libbase_ver)',
+            'libbrillo-<(libbase_ver)',
+            'libbrillo-test-<(libbase_ver)',
+            'libbrillo-glib-<(libbase_ver)',
           ],
           'variables': {
             'deps': [
diff --git a/libbrillo.pc.in b/libbrillo.pc.in
new file mode 100644
index 0000000..893d71e
--- /dev/null
+++ b/libbrillo.pc.in
@@ -0,0 +1,7 @@
+bslot=@BSLOT@
+
+Name: libbrillo
+Description: brillo base library
+Version: ${bslot}
+Requires.private: @PRIVATE_PC@
+Libs: -lbrillo-${bslot}
diff --git a/libchromeos-glib.pc.in b/libchromeos-glib.pc.in
deleted file mode 100644
index db40d19..0000000
--- a/libchromeos-glib.pc.in
+++ /dev/null
@@ -1,8 +0,0 @@
-bslot=@BSLOT@
-
-Name: libchromeos-glib
-Description: chromeos glib wrapper library
-Version: ${bslot}
-Requires.private: @PRIVATE_PC@
-Libs: -lchromeos-glib-${bslot}
-
diff --git a/libchromeos-test.pc.in b/libchromeos-test.pc.in
deleted file mode 100644
index 794f177..0000000
--- a/libchromeos-test.pc.in
+++ /dev/null
@@ -1,8 +0,0 @@
-bslot=@BSLOT@
-
-Name: libchromeos-test
-Description: chromeos test library
-Version: ${bslot}
-# Because libchromeos-test is static, we have to depend directly on everything.
-Requires: @PRIVATE_PC@
-Libs: -lchromeos-test-${bslot}
diff --git a/libchromeos.gyp b/libchromeos.gyp
deleted file mode 100644
index 5c05b51..0000000
--- a/libchromeos.gyp
+++ /dev/null
@@ -1,6 +0,0 @@
-{
-  'includes': [
-    'libchromeos-334380.gypi',
-    'libpolicy.gypi',
-  ]
-}
diff --git a/libchromeos.pc.in b/libchromeos.pc.in
deleted file mode 100644
index ec86d5e..0000000
--- a/libchromeos.pc.in
+++ /dev/null
@@ -1,7 +0,0 @@
-bslot=@BSLOT@
-
-Name: libchromeos
-Description: chromeos base library
-Version: ${bslot}
-Requires.private: @PRIVATE_PC@
-Libs: -lchromeos-${bslot}
diff --git a/policy/device_policy.h b/policy/device_policy.h
index 12a21fd..7a60a65 100644
--- a/policy/device_policy.h
+++ b/policy/device_policy.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_POLICY_DEVICE_POLICY_H_
-#define LIBCHROMEOS_POLICY_DEVICE_POLICY_H_
+#ifndef LIBBRILLO_POLICY_DEVICE_POLICY_H_
+#define LIBBRILLO_POLICY_DEVICE_POLICY_H_
 
 #include <stdint.h>
 
@@ -160,4 +160,4 @@
 
 #pragma GCC visibility pop
 
-#endif  // LIBCHROMEOS_POLICY_DEVICE_POLICY_H_
+#endif  // LIBBRILLO_POLICY_DEVICE_POLICY_H_
diff --git a/policy/device_policy_impl.h b/policy/device_policy_impl.h
index 458cd35..7174ce1 100644
--- a/policy/device_policy_impl.h
+++ b/policy/device_policy_impl.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_POLICY_DEVICE_POLICY_IMPL_H_
-#define LIBCHROMEOS_POLICY_DEVICE_POLICY_IMPL_H_
+#ifndef LIBBRILLO_POLICY_DEVICE_POLICY_IMPL_H_
+#define LIBBRILLO_POLICY_DEVICE_POLICY_IMPL_H_
 
 #include <set>
 #include <string>
@@ -84,4 +84,4 @@
 
 #pragma GCC visibility pop
 
-#endif  // LIBCHROMEOS_POLICY_DEVICE_POLICY_IMPL_H_
+#endif  // LIBBRILLO_POLICY_DEVICE_POLICY_IMPL_H_
diff --git a/policy/libpolicy.h b/policy/libpolicy.h
index e2df0c3..c916305 100644
--- a/policy/libpolicy.h
+++ b/policy/libpolicy.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_POLICY_LIBPOLICY_H_
-#define LIBCHROMEOS_POLICY_LIBPOLICY_H_
+#ifndef LIBBRILLO_POLICY_LIBPOLICY_H_
+#define LIBBRILLO_POLICY_LIBPOLICY_H_
 
 #include <string>
 
@@ -47,4 +47,4 @@
 
 #pragma GCC visibility pop
 
-#endif  // LIBCHROMEOS_POLICY_LIBPOLICY_H_
+#endif  // LIBBRILLO_POLICY_LIBPOLICY_H_
diff --git a/policy/mock_device_policy.h b/policy/mock_device_policy.h
index aeb8dd8..bd53787 100644
--- a/policy/mock_device_policy.h
+++ b/policy/mock_device_policy.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_POLICY_MOCK_DEVICE_POLICY_H_
-#define LIBCHROMEOS_POLICY_MOCK_DEVICE_POLICY_H_
+#ifndef LIBBRILLO_POLICY_MOCK_DEVICE_POLICY_H_
+#define LIBBRILLO_POLICY_MOCK_DEVICE_POLICY_H_
 
 #include <set>
 #include <string>
@@ -104,4 +104,4 @@
 
 #pragma GCC visibility pop
 
-#endif  // LIBCHROMEOS_POLICY_MOCK_DEVICE_POLICY_H_
+#endif  // LIBBRILLO_POLICY_MOCK_DEVICE_POLICY_H_
diff --git a/policy/mock_libpolicy.h b/policy/mock_libpolicy.h
index 04fe92d..acb9b8b 100644
--- a/policy/mock_libpolicy.h
+++ b/policy/mock_libpolicy.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef LIBCHROMEOS_POLICY_MOCK_LIBPOLICY_H_
-#define LIBCHROMEOS_POLICY_MOCK_LIBPOLICY_H_
+#ifndef LIBBRILLO_POLICY_MOCK_LIBPOLICY_H_
+#define LIBBRILLO_POLICY_MOCK_LIBPOLICY_H_
 
 #include <gmock/gmock.h>
 #include <set>
@@ -32,4 +32,4 @@
 
 #pragma GCC visibility pop
 
-#endif  // LIBCHROMEOS_POLICY_MOCK_LIBPOLICY_H_
+#endif  // LIBBRILLO_POLICY_MOCK_LIBPOLICY_H_
diff --git a/platform2_preinstall.sh b/platform2_preinstall.sh
index ecd015d..448a31a 100755
--- a/platform2_preinstall.sh
+++ b/platform2_preinstall.sh
@@ -9,44 +9,44 @@
 OUT=$1
 shift
 for v; do
   # Extract all the libchromeos sublibs from 'dependencies' section of
   # 'libchromeos-<(libbase_ver)' target in libchromeos.gypi and convert them
   # into an array of "-lchromeos-<sublib>-<v>" flags.
   sublibs=($(sed -n "
-     /'target_name': 'libchromeos-<(libbase_ver)'/,/target_name/ {
+     /'target_name': 'libbrillo-<(libbase_ver)'/,/target_name/ {
        /dependencies/,/],/ {
-         /libchromeos/ {
+         /libbrillo/ {
            s:[',]::g
            s:<(libbase_ver):${v}:g
-           s:libchromeos:-lchromeos:
+           s:libbrillo:-lbrillo:
            p
          }
        }
-     }" libchromeos.gypi))
+     }" libbrillo.gypi))
 
-  echo "GROUP ( AS_NEEDED ( ${sublibs[@]} ) )" > "${OUT}"/lib/libchromeos-${v}.so
+  echo "GROUP ( AS_NEEDED ( ${sublibs[@]} ) )" > "${OUT}"/lib/libbrillo-${v}.so
 
-  deps=$(<"${OUT}"/gen/libchromeos-${v}-deps.txt)
-  pc="${OUT}"/lib/libchromeos-${v}.pc
+  deps=$(<"${OUT}"/gen/libbrillo-${v}-deps.txt)
+  pc="${OUT}"/lib/libbrillo-${v}.pc
 
   sed \
     -e "s/@BSLOT@/${v}/g" \
     -e "s/@PRIVATE_PC@/${deps}/g" \
-    "libchromeos.pc.in" > "${pc}"
+    "libbrillo.pc.in" > "${pc}"
 
-  deps_test=$(<"${OUT}"/gen/libchromeos-test-${v}-deps.txt)
-  deps_test+=" libchromeos-${v}"
+  deps_test=$(<"${OUT}"/gen/libbrillo-test-${v}-deps.txt)
+  deps_test+=" libbrillo-${v}"
   sed \
     -e "s/@BSLOT@/${v}/g" \
     -e "s/@PRIVATE_PC@/${deps_test}/g" \
-    "libchromeos-test.pc.in" > "${OUT}/lib/libchromeos-test-${v}.pc"
+    "libbrillo-test.pc.in" > "${OUT}/lib/libbrillo-test-${v}.pc"
 
 
-  deps_glib=$(<"${OUT}"/gen/libchromeos-glib-${v}-deps.txt)
-  pc_glib="${OUT}"/lib/libchromeos-glib-${v}.pc
+  deps_glib=$(<"${OUT}"/gen/libbrillo-glib-${v}-deps.txt)
+  pc_glib="${OUT}"/lib/libbrillo-glib-${v}.pc
 
   sed \
     -e "s/@BSLOT@/${v}/g" \
     -e "s/@PRIVATE_PC@/${deps_glib}/g" \
-    "libchromeos-glib.pc.in" > "${pc_glib}"
+    "libbrillo-glib.pc.in" > "${pc_glib}"
 done
@@ -9,44 +9,44 @@
 shift
 for v; do
-  # Extract all the libchromeos sublibs from 'dependencies' section of
-  # 'libchromeos-<(libbase_ver)' target in libchromeos.gypi and convert them
-  # into an array of "-lchromeos-<sublib>-<v>" flags.
+  # Extract all the libbrillo sublibs from 'dependencies' section of
+  # 'libbrillo-<(libbase_ver)' target in libbrillo.gypi and convert them
+  # into an array of "-lbrillo-<sublib>-<v>" flags.
   sublibs=($(sed -n "